# ozi-templates CHANGELOG
## 2.19.1 (2024-12-31)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.27.9 to 3.28.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.9 to 3.28.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/df409f7d9260372bd5f19e5b04e83cb3c43714ae...48ab28a6f5dbc2a99bf1e0131198dd8f1df78169)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b29e326`](https://github.com/OZI-Project/ozi-templates/commit/b29e3269e92a59b562968f1ff53f8e39c9d8dd65))


### 🐛 Fixed Bugs

*  add ``.mypy_cache`` to .gitignore template — rjdbcm <rjdbcm@outlook.com>
([`a5c767c`](https://github.com/OZI-Project/ozi-templates/commit/a5c767c0d07ee4aacc5f0da45b5a972008c1e2ac))

## 2.19.0 (2024-12-20)


### 🐛 Fixed Bugs

*  update metadata for OZI.build 1.8.2 — rjdbcm <rjdbcm@outlook.com>
([`8868369`](https://github.com/OZI-Project/ozi-templates/commit/8868369fcad95b613c68d71100c2de70d0630aa1))


### ✨ Implemented Features

*  OZI.build 1.8.2 metadata — rjdbcm <rjdbcm@outlook.com>
([`fcc556e`](https://github.com/OZI-Project/ozi-templates/commit/fcc556e2956e3cc25cba7cc76b9e482ce77ec736))


### Other


* Update ozi.wrap — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`dc721ca`](https://github.com/OZI-Project/ozi-templates/commit/dc721ca93c7b4161c15be6f9e9d4e772e7540c82))

## 2.18.0 (2024-12-19)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.4.3 to 4.5.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.4.3 to 4.5.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/b4b15b8c7c6ac21ea08fcf65892d2ee8f75cf882...6f51ac03b9356f520e9adb1b1b7802705f340c2b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5e38f8a`](https://github.com/OZI-Project/ozi-templates/commit/5e38f8ac6d75b4c9d6b6f792211aa7e73b99cea0))

*  Bump OZI-Project/draft from 1.6.3 to 1.7.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.6.3 to 1.7.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/b462b01f7f92a361d92233a8c2d326276c2d91a3...c0d23e778c413e1f5c7ca9555a1ec190c9e48cbd)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d9b58bc`](https://github.com/OZI-Project/ozi-templates/commit/d9b58bc2ad7c73fa748bbbcf6fcc8a17870ca23e))

*  Bump OZI-Project/publish from 1.7.1 to 1.7.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.7.1 to 1.7.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/8e64c6d501bee7b5b0db5247cd761085d411d1bf...67952e32de84496a2ed2729ffbc612a63d4ede47)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9c55304`](https://github.com/OZI-Project/ozi-templates/commit/9c55304cd6513fbe3dd171cf6c575af6a8acb75c))


### ✨ Implemented Features

*  update for spec v0.16

ozi-spec now hosts the lists of endpoints for CI provider workflows. — rjdbcm <rjdbcm@outlook.com>
([`d89350c`](https://github.com/OZI-Project/ozi-templates/commit/d89350c01df2685ce0b5b8117b116adcefdeae76))


### Other


* Create purge-artifacts.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`3436bbb`](https://github.com/OZI-Project/ozi-templates/commit/3436bbb566948198f7d3eed3f8ecea1c138af450))

## 2.17.0 (2024-12-17)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.27.5 to 3.27.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.5 to 3.27.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f09c1c0a94de965c15400f5634aa42fac8fb8f88...df409f7d9260372bd5f19e5b04e83cb3c43714ae)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2cce826`](https://github.com/OZI-Project/ozi-templates/commit/2cce826983dc58ed6c0b5673300acedabffa07ee))

*  Bump OZI-Project/release from 1.0.5 to 1.1.2

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.5 to 1.1.2.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/1a3cb28a9a9d51fa8e333740a8b863c0f23ab3da...0e2db492d3d36479eadc1ba15e509e911816bc39)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`aff7ebd`](https://github.com/OZI-Project/ozi-templates/commit/aff7ebd0244bd584477ccccb6288335c6fcaf973))

*  Bump OZI-Project/draft from 1.5.0 to 1.6.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.5.0 to 1.6.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/e872ff9cded28eb22d937ba3fd9abfe4fc489239...b462b01f7f92a361d92233a8c2d326276c2d91a3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`cb3f719`](https://github.com/OZI-Project/ozi-templates/commit/cb3f719ef1d8528c406008e54bfffb1dc234be0a))

*  Bump OZI-Project/checkpoint from 1.2.1 to 1.4.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.2.1 to 1.4.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/32b9310f480343c946214e3ea4b637202eaa312a...5eb7b6ec9ba2eec71a0418270d92e9a6d81d285f)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ddebb82`](https://github.com/OZI-Project/ozi-templates/commit/ddebb82fdd0b96bde8d5b1cf6001c3f25ebcd1c7))

*  Bump OZI-Project/publish from 1.5.0 to 1.7.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.5.0 to 1.7.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/3ff1ebdd9edd89b30c126e0cf78e2d9754c0f9fa...8e64c6d501bee7b5b0db5247cd761085d411d1bf)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`5301d03`](https://github.com/OZI-Project/ozi-templates/commit/5301d03ad3b6e729cd77a56564783ab3a0f45977))


### 🐛 Fixed Bugs

*  remove optional dependency groups — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`bbb7faf`](https://github.com/OZI-Project/ozi-templates/commit/bbb7faf5e9fb553da88864e61baaa99c24aa9a7e))


### ✨ Implemented Features

*  add spec 0.15 endpoints — rjdbcm <rjdbcm@outlook.com>
([`8113277`](https://github.com/OZI-Project/ozi-templates/commit/8113277eaf1d5759ec4ed0e98bfc8ff5cb0c0464))

*  move pypa/gh-action-pypi-publish from composite workflow to template — rjdbcm <rjdbcm@outlook.com>
([`106f183`](https://github.com/OZI-Project/ozi-templates/commit/106f183057f2afb7b29c075601d427530ca6cd53))


### Other


* Update ozi.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`128a552`](https://github.com/OZI-Project/ozi-templates/commit/128a55255ea547316e2ca65d9bd8830bf595ebec))

* Update ozi.yml endpoints — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`ec7bf5b`](https://github.com/OZI-Project/ozi-templates/commit/ec7bf5b0505444f95b23792f3d82f8917a222631))

## 2.16.0 (2024-11-28)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.10.1 to 2.10.2

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.10.1 to 2.10.2.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/91182cccc01eb5e619899d80e4e971d6181294a7...0080882f6c36860b6ba35c610c98ce87d4e2f26f)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`db0be0a`](https://github.com/OZI-Project/ozi-templates/commit/db0be0a7029f506994a74b3059eeeb95aaa1fe75))

*  Bump github/codeql-action from 3.27.4 to 3.27.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.4 to 3.27.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ea9e4e37992a54ee68a9622e985e60c8e8f12d9f...f09c1c0a94de965c15400f5634aa42fac8fb8f88)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`907c1f4`](https://github.com/OZI-Project/ozi-templates/commit/907c1f445ae840969ca08a3e5ffc5b78d53a46ab))

*  Bump actions/dependency-review-action from 4.4.0 to 4.5.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.4.0 to 4.5.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/4081bf99e2866ebe428fc0477b69eb4fcda7220a...3b139cfc5fae8b618d3eae3675e383bb1769c019)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`13c36af`](https://github.com/OZI-Project/ozi-templates/commit/13c36af2185a9529fa040e0798915236bd561da5))


### ✨ Implemented Features

*  License :: OSI Approved :: MIT No Attribution License (MIT-0)

Public domain equivalent for other legal jurisdictions. — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`57c339b`](https://github.com/OZI-Project/ozi-templates/commit/57c339b30b2572d3249c27c003f68892ec9d5a52))


### Other


* feat: update license to MIT-0 removing explicit public domain attribution — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8f02111`](https://github.com/OZI-Project/ozi-templates/commit/8f02111cabd39b1b06ae6fc487c3fd29ecec221a))

## 2.15.1 (2024-11-25)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.27.3 to 3.27.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.3 to 3.27.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/396bb3e45325a47dd9ef434068033c6d5bb0d11a...ea9e4e37992a54ee68a9622e985e60c8e8f12d9f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`12d215d`](https://github.com/OZI-Project/ozi-templates/commit/12d215d03cacf17c54a899b9fd31fe9298be9343))


### Other


* fix: set requires-python='>=3.10, <3.14' — rjdbcm <rjdbcm@outlook.com>
([`a4d81c2`](https://github.com/OZI-Project/ozi-templates/commit/a4d81c215d062cfc06c989f490dc4ee9bb548be9))

## 2.15.0 (2024-11-18)


### ✨ Implemented Features

*  use spec 0.12.1 harden_runner.version — rjdbcm <rjdbcm@outlook.com>
([`f110db5`](https://github.com/OZI-Project/ozi-templates/commit/f110db5a9656df88c9ed4c15c9c2f725af2899f5))

## 2.14.0 (2024-11-15)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 1.0.4 to 1.0.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.4 to 1.0.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/74350f112641257ed33f06f83c3e6fc7ae92059b...1a3cb28a9a9d51fa8e333740a8b863c0f23ab3da)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`2a6b474`](https://github.com/OZI-Project/ozi-templates/commit/2a6b474214d03e17ecc6ed16fbf5e2d9fad51eb7))

*  Bump OZI-Project/publish from 1.4.1 to 1.5.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/42b2c7502712c4bfec2bebf507c01282ce769912...3ff1ebdd9edd89b30c126e0cf78e2d9754c0f9fa)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f42ce42`](https://github.com/OZI-Project/ozi-templates/commit/f42ce42d0b04cd23d90d3de3f91210fbcf4439fc))

*  Bump OZI-Project/draft from 1.4.1 to 1.5.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.1 to 1.5.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/9b883f1803600651f4cf46c98c767c5efe9bad48...e872ff9cded28eb22d937ba3fd9abfe4fc489239)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`b17f760`](https://github.com/OZI-Project/ozi-templates/commit/b17f7600200c3a3647b868884da6d943edee580e))


### ✨ Implemented Features

* (generate_provenance.yml.j2): use specification build provenance version in template — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`6a734f2`](https://github.com/OZI-Project/ozi-templates/commit/6a734f2013f28662cf08a7424a16ddb5888b5262))

## 2.13.15 (2024-11-11)

## 2.13.14 (2024-11-10)

## 2.13.13 (2024-11-10)


### ⬇️ Downgraded Dependencies

*  OZI-Project/publish 1.4.2 revert to 1.4.1 — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`9a79419`](https://github.com/OZI-Project/ozi-templates/commit/9a7941980a2e26cbf3eb035cff985798fa181a95))


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 1.4.0 to 1.4.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/d797368c9870f3ca16373680b52db1ed4c333f21...9b883f1803600651f4cf46c98c767c5efe9bad48)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e163dac`](https://github.com/OZI-Project/ozi-templates/commit/e163dac67ee16302ec983f3adad307ac031d5537))

*  Bump OZI-Project/checkpoint from 1.1.1 to 1.2.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.1.1 to 1.2.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/ac0c03fc08ac2e7e4b4fbdf02249109384596313...32b9310f480343c946214e3ea4b637202eaa312a)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0fea4a8`](https://github.com/OZI-Project/ozi-templates/commit/0fea4a85fc04323043b32848413960de6a6c629f))

*  Bump github/codeql-action from 3.27.0 to 3.27.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.27.0 to 3.27.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/662472033e021d55d94146f66f6058822b0b39fd...396bb3e45325a47dd9ef434068033c6d5bb0d11a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`42ff68b`](https://github.com/OZI-Project/ozi-templates/commit/42ff68bd30079a419ec77f587aabc0c424dab405))

*  Bump OZI-Project/publish from 1.4.1 to 1.4.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.1 to 1.4.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/42b2c7502712c4bfec2bebf507c01282ce769912...c5720ae47546df65ca1dcffd5a097f266928b453)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`cf13204`](https://github.com/OZI-Project/ozi-templates/commit/cf13204a0f14c5388926958fc26bb0adc1da9885))


### 🐛 Fixed Bugs

*  fix tox template for windows compatibility — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`a89893e`](https://github.com/OZI-Project/ozi-templates/commit/a89893e678b1ea54b4b0344fbc4cd9c51f5053d2))

*  root children now findable by rewriter — rjdbcm <rjdbcm@outlook.com>
([`dd07905`](https://github.com/OZI-Project/ozi-templates/commit/dd07905bea79d59bd62f7028f9434ccf0f7a39a2))

*  fix meson.build templates to allow the rewriter to find arrays — rjdbcm <rjdbcm@outlook.com>
([`52c5352`](https://github.com/OZI-Project/ozi-templates/commit/52c5352cf695218a5033ef32afb6117375a931e4))


### Other


* fix: escape path sep in tox template for cross-platform use — rjdbcm <rjdbcm@outlook.com>
([`df498fc`](https://github.com/OZI-Project/ozi-templates/commit/df498fcf5e1b9c09ad1ecdfbd3838c8631ec4ae0))

## 2.13.12 (2024-11-07)

## 2.13.11 (2024-11-06)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 1.4.0 to 1.4.1

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.4.0 to 1.4.1.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/a8bb776353d5b9f9bd678ef5ab2cd38bf5d4ad0f...42b2c7502712c4bfec2bebf507c01282ce769912)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ba76960`](https://github.com/OZI-Project/ozi-templates/commit/ba7696009f6210ba127922d6f0da715a1e856afa))

## 2.13.10 (2024-11-05)


### 🐛 Fixed Bugs

*  make root folder children findable for meson rewriter — rjdbcm <rjdbcm@outlook.com>
([`66ee49d`](https://github.com/OZI-Project/ozi-templates/commit/66ee49d0715308455b2b1d95bbc8601c6e8b5372))

*  fix rewriter hooks — rjdbcm <rjdbcm@outlook.com>
([`b55e941`](https://github.com/OZI-Project/ozi-templates/commit/b55e941dba391030db4fe939c9f889ac9da8a959))


### 🔨 Updated Scripts

* (publish): add github.com to allowed endpoints — rjdbcm <rjdbcm@outlook.com>
([`9e4c63b`](https://github.com/OZI-Project/ozi-templates/commit/9e4c63bf4b7ba85cca3857a9b84e60f86b85e840))


### Other


* 👷 force patch 

Merge pull request #269 from OZI-Project/main
([`5bb352f`](https://github.com/OZI-Project/ozi-templates/commit/5bb352f3bc835a29b54ea440bcd7ba79bf3705dc))

* perf: improved test coverage — rjdbcm <rjdbcm@outlook.com>
([`008c14a`](https://github.com/OZI-Project/ozi-templates/commit/008c14aabedcb836c121b4bf101fa7f644cd3546))

* perf: coverage excluded for typechecking blocks — rjdbcm <rjdbcm@outlook.com>
([`69eb26a`](https://github.com/OZI-Project/ozi-templates/commit/69eb26a7913a422405acf361c683741868426a3e))

## 2.13.9 (2024-11-01)


### 🐛 Fixed Bugs

*  add missing optional dist deps — rjdbcm <rjdbcm@outlook.com>
([`98f44fe`](https://github.com/OZI-Project/ozi-templates/commit/98f44fe750d16630caef5ce5d733de0b7eb4f199))


### Other


* fix: cleanup template whitespace and rendered comments — rjdbcm <rjdbcm@outlook.com>
([`62b4c66`](https://github.com/OZI-Project/ozi-templates/commit/62b4c662b8820fd6e6bbe7cef5bad13ffcac8270))

* perf: pyproject template skips empty keys — rjdbcm <rjdbcm@outlook.com>
([`520a5d3`](https://github.com/OZI-Project/ozi-templates/commit/520a5d39013eb0bade03cee6bb9306c85bc9171c))

* Update dependabot.yml — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`8c90dbd`](https://github.com/OZI-Project/ozi-templates/commit/8c90dbd21346aa7e950337e5893c6101d408380d))

## 2.13.8 (2024-10-31)


### ✏️ Corrected Typos

*  remove repeated checkpoints — rjdbcm <rjdbcm@outlook.com>
([`f750bc5`](https://github.com/OZI-Project/ozi-templates/commit/f750bc56c1f06bed34034ff2c997bfc26c6041a0))

## 2.13.7 (2024-10-31)


### ⬆️ Upgraded Dependencies

*  step-security/harden-runner defaults to v2.10.1 — rjdbcm <rjdbcm@outlook.com>
([`293494f`](https://github.com/OZI-Project/ozi-templates/commit/293494f36ac9ee279eef0aee6cb914344e2cc9b0))


### ✏️ Corrected Typos

*  rewrite harden runner template — rjdbcm <rjdbcm@outlook.com>
([`9d20663`](https://github.com/OZI-Project/ozi-templates/commit/9d20663b243ebdb843ad696db34a7ca7798f71b4))

## 2.13.6 (2024-10-31)


### ✏️ Corrected Typos

*  remove required block — rjdbcm <rjdbcm@outlook.com>
([`b0788d1`](https://github.com/OZI-Project/ozi-templates/commit/b0788d1a2d3bb6ae830012a47c0aff916c8781f0))

## 2.13.5 (2024-10-31)


### ✏️ Corrected Typos

*  template path for harden_runner — rjdbcm <rjdbcm@outlook.com>
([`d9be6cb`](https://github.com/OZI-Project/ozi-templates/commit/d9be6cb6c0ea88b70268d945025e1e555d789cee))

## 2.13.4 (2024-10-31)


### ✏️ Corrected Typos

*  template syntax checkpoint final check — rjdbcm <rjdbcm@outlook.com>
([`a258ae2`](https://github.com/OZI-Project/ozi-templates/commit/a258ae2e7df56bf9daf99597f39d421191c78ab0))

## 2.13.3 (2024-10-31)


### 🐛 Fixed Bugs

*  template syntax checkpoint final check — rjdbcm <rjdbcm@outlook.com>
([`412b455`](https://github.com/OZI-Project/ozi-templates/commit/412b455dac87467cab864781cd031cea86549b19))

*  template syntax checkpoint final check — rjdbcm <rjdbcm@outlook.com>
([`d55b5f3`](https://github.com/OZI-Project/ozi-templates/commit/d55b5f32e2a8e96eb94452b0db4631de3456b704))

## 2.13.2 (2024-10-31)


### 🐛 Fixed Bugs

*  template syntax checkpoint final check — rjdbcm <rjdbcm@outlook.com>
([`98e4960`](https://github.com/OZI-Project/ozi-templates/commit/98e49608d432c6bf53e721d6b3ec73c1e0a1d81b))

## 2.13.1 (2024-10-31)


### ⬆️ Upgraded Dependencies

*  Bump actions/dependency-review-action from 4.3.5 to 4.4.0

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.5 to 4.4.0.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/a6993e2c61fd5dc440b409aa1d6904921c5e1894...4081bf99e2866ebe428fc0477b69eb4fcda7220a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`6955d53`](https://github.com/OZI-Project/ozi-templates/commit/6955d536882934c1b6bc493324095a4abf5b1c04))


### 🐛 Fixed Bugs

*  dont render endpoints for checkpoint final check — rjdbcm <rjdbcm@outlook.com>
([`2222516`](https://github.com/OZI-Project/ozi-templates/commit/2222516c6860fb86401c2fe0f2691b83a7ee65d8))

*  add sigstore endpoints to publish harden runner — rjdbcm <rjdbcm@outlook.com>
([`7f98863`](https://github.com/OZI-Project/ozi-templates/commit/7f988635f9f4be6e1df3434ec47517f37635ce7c))


### 🔨 Updated Scripts

*  add sigstore signing endpoints to publish workflow — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`e8f9879`](https://github.com/OZI-Project/ozi-templates/commit/e8f9879b5e33ef27ef6466b900b0c52ad0d0879d))

## 2.13.0 (2024-10-28)


### ✨ Implemented Features

*  support for rendering simple SPDX license expressions containing 'and', 'or', 'with' (cannot contain parenthesis) — rjdbcm <rjdbcm@outlook.com>
([`23f3e5e`](https://github.com/OZI-Project/ozi-templates/commit/23f3e5e2b2efa1f4bbf6377147fca814916085c0))

## 2.12.7 (2024-10-27)


### 🐛 Fixed Bugs

*  fix variable type in license exception template — rjdbcm <rjdbcm@outlook.com>
([`9ab67af`](https://github.com/OZI-Project/ozi-templates/commit/9ab67af4bb86ec5029508ca81826182f2d9f723c))

*  fix variable scope in license exception template — rjdbcm <rjdbcm@outlook.com>
([`2bd62fa`](https://github.com/OZI-Project/ozi-templates/commit/2bd62fa36c5d0608bc1487e905e17e66255d7a5f))

## 2.12.6 (2024-10-27)


### ⬆️ Upgraded Dependencies

*  OZI 1.24 — rjdbcm <rjdbcm@outlook.com>
([`1ecd309`](https://github.com/OZI-Project/ozi-templates/commit/1ecd309e03d8650c7d68cb7797bb8556a7dae078))

*  Bump actions/checkout from 4.2.1 to 4.2.2

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.2.1 to 4.2.2.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/eef61447b9ff4aafe5dcd4e0bbf5d482be7e7871...11bd71901bbe5b1630ceea73d27597364c9af683)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`af1fa58`](https://github.com/OZI-Project/ozi-templates/commit/af1fa580c2709cbbcb198a4bcf8f54591f085ebc))

*  Bump OZI-Project/checkpoint from 1.0.2 to 1.1.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.2 to 1.1.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/fff79a1993b9a0822e7b594dcbdb164a7cff4292...ac0c03fc08ac2e7e4b4fbdf02249109384596313)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`41e0fd7`](https://github.com/OZI-Project/ozi-templates/commit/41e0fd706d18776ae3a438165779cb5a6f3f805a))


### 🐛 Fixed Bugs

*  license exception parsing conditional fixed — rjdbcm <rjdbcm@outlook.com>
([`043ee04`](https://github.com/OZI-Project/ozi-templates/commit/043ee04276e0832bd2b3d8f250384b0fe66dd413))

*  license exception parsing case-insensitive — rjdbcm <rjdbcm@outlook.com>
([`4ce0f3f`](https://github.com/OZI-Project/ozi-templates/commit/4ce0f3f0813350980e38b01d68846e845e6f6280))


### Other


* Update SECURITY.md — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`b97c577`](https://github.com/OZI-Project/ozi-templates/commit/b97c577072d0eefa50b3b04b0de4e6b4eea332d6))

## 2.12.5 (2024-10-24)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 1.3.0 to 1.4.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/50e1883d3f02c37133eb0b38d726dff6b63554a0...a8bb776353d5b9f9bd678ef5ab2cd38bf5d4ad0f)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`4b35a75`](https://github.com/OZI-Project/ozi-templates/commit/4b35a75536c22396881414f3b1b38b1b7f8b82fd))

*  Bump OZI-Project/draft from 1.3.0 to 1.4.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.3.0 to 1.4.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/abc015e6e3bc08e765025befc25f2bd355ddb79d...d797368c9870f3ca16373680b52db1ed4c333f21)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c225ff9`](https://github.com/OZI-Project/ozi-templates/commit/c225ff9fb893aecbcb91d1269cde50e5994de701))

*  Bump actions/dependency-review-action from 4.3.4 to 4.3.5

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5a2ce3f5b92ee19cbb1541a4984c76d921601d7c...a6993e2c61fd5dc440b409aa1d6904921c5e1894)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3da9179`](https://github.com/OZI-Project/ozi-templates/commit/3da9179214f4111e85486e02d24f6d446b7d9fc9))

*  Bump github/codeql-action from 3.26.13 to 3.27.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.13 to 3.27.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f779452ac5af1c261dce0346a8f964149f49322b...662472033e021d55d94146f66f6058822b0b39fd)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`3fa9480`](https://github.com/OZI-Project/ozi-templates/commit/3fa948096ba88815e4c899c87cc59071f94ffa1c))


### 🏷️


* fix metadata globals type to match ozi-spec — rjdbcm <rjdbcm@outlook.com>
([`249e448`](https://github.com/OZI-Project/ozi-templates/commit/249e448ef1d6c9cd978807c5c42b55a490a6f294))


### 🔨 Updated Configuration

*  lint-timeout-multiplier set to 3 — rjdbcm <rjdbcm@outlook.com>
([`240d528`](https://github.com/OZI-Project/ozi-templates/commit/240d5282adbb484280c417d7f2e6688f23fd23bc))


### Other


* 👷(subprojects/ozi.wrap): release/1.23 — rjdbcm <rjdbcm@outlook.com>
([`7f9228f`](https://github.com/OZI-Project/ozi-templates/commit/7f9228f8a2cc9068782b1654c51f26e2ec31cf87))

## 2.12.4 (2024-10-16)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.4.0 to 4.4.3

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.4.0 to 4.4.3.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/50769540e7f4bd5e21e526ee35c689e35e0d6874...b4b15b8c7c6ac21ea08fcf65892d2ee8f75cf882)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`53a6740`](https://github.com/OZI-Project/ozi-templates/commit/53a674000869273995eec514c316206a6a62a013))

*  Bump github/codeql-action from 3.26.12 to 3.26.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.12 to 3.26.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/c36620d31ac7c881962c3d9dd939c40ec9434f2b...f779452ac5af1c261dce0346a8f964149f49322b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3f330b4`](https://github.com/OZI-Project/ozi-templates/commit/3f330b4e8ffd0ac28ef8dd3a6f9387eace36d6ec))


### 🐛 Fixed Bugs

*  fix missing quotes for enable_uv options — rjdbcm <rjdbcm@outlook.com>
([`d30f6fc`](https://github.com/OZI-Project/ozi-templates/commit/d30f6fcf246070ddd73dcc150086afe24bc3e1e4))

## 2.12.3 (2024-10-14)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 1.0.3 to 1.0.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.3 to 1.0.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/d764d82aa0900effc1590b0281ff35d67be592fd...74350f112641257ed33f06f83c3e6fc7ae92059b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`051afc5`](https://github.com/OZI-Project/ozi-templates/commit/051afc5dccc3c5b07aaa8fbee96100dd08bed7cd))

*  Bump OZI-Project/checkpoint from 1.0.1 to 1.0.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.1 to 1.0.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/38b742bcf99a1eae353d2f750d23f7a0c0e2174d...fff79a1993b9a0822e7b594dcbdb164a7cff4292)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f07c6dc`](https://github.com/OZI-Project/ozi-templates/commit/f07c6dc553c15674a4f397225db743c1bac95379))

*  Bump github/codeql-action from 3.26.9 to 3.26.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.9 to 3.26.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/461ef6c76dfe95d5c364de2f431ddbd31a417628...c36620d31ac7c881962c3d9dd939c40ec9434f2b)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad70765`](https://github.com/OZI-Project/ozi-templates/commit/ad70765bb311d199df3d8c6b4ec55913c21d1035))

*  Bump OZI-Project/publish from 1.1.0 to 1.3.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.1.0 to 1.3.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/6a44652f29d676922cf9e10d3ebc39b723078729...50e1883d3f02c37133eb0b38d726dff6b63554a0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`f4415d3`](https://github.com/OZI-Project/ozi-templates/commit/f4415d36f399fe89a4703c7dc3a227769fb9c251))

*  Bump OZI-Project/draft from 1.1.0 to 1.3.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.1.0 to 1.3.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/23eab64fb44d03215598b6fffcfff890bfb7ec4b...abc015e6e3bc08e765025befc25f2bd355ddb79d)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c4b9ec1`](https://github.com/OZI-Project/ozi-templates/commit/c4b9ec1a30fa8414817d648478cf47311868a87d))


### 🐛 Fixed Bugs

*  add missing py.typed — rjdbcm <rjdbcm@outlook.com>
([`fb9371b`](https://github.com/OZI-Project/ozi-templates/commit/fb9371babedab3a73e89287446290213ab97f56a))

## 2.12.2 (2024-10-09)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 1.0.0 to 1.0.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 1.0.0 to 1.0.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/b53cf4f0aeb004d5980b72675fba6a38dcc66674...38b742bcf99a1eae353d2f750d23f7a0c0e2174d)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e6cf417`](https://github.com/OZI-Project/ozi-templates/commit/e6cf4170d5d41d4a8f045a145b16dbbe05384342))

*  Bump OZI-Project/draft from 1.0.0 to 1.1.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 1.0.0 to 1.1.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/7e8ad70f472504510e169567e97db01bdafe2533...23eab64fb44d03215598b6fffcfff890bfb7ec4b)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`65b76a3`](https://github.com/OZI-Project/ozi-templates/commit/65b76a32e09490f9f5f85abd1a7ad9a3607b94be))

*  Bump OZI-Project/publish from 1.0.0 to 1.1.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 1.0.0 to 1.1.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/55904e4f59084e7c6ccfad7b158db52a360e1f54...6a44652f29d676922cf9e10d3ebc39b723078729)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`506cdc5`](https://github.com/OZI-Project/ozi-templates/commit/506cdc5cfaf44ec52ca3eb424a2a7604061d933c))

*  Bump OZI-Project/release from 1.0.0 to 1.0.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 1.0.0 to 1.0.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/98248899bb8b235e3198105f080093ea5b9751d8...d764d82aa0900effc1590b0281ff35d67be592fd)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1436b21`](https://github.com/OZI-Project/ozi-templates/commit/1436b218326f42a5f1eb524897d3a816193a3d8f))

*  Bump actions/checkout from 4.1.7 to 4.2.1

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.7 to 4.2.1.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/692973e3d937129bcbf40652eb9f2f61becf3332...eef61447b9ff4aafe5dcd4e0bbf5d482be7e7871)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`0987808`](https://github.com/OZI-Project/ozi-templates/commit/09878082515eca234956af2b84ca03ce2a49860e))

*  Bump github/codeql-action from 3.26.8 to 3.26.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.8 to 3.26.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/294a9d92911152fe08befb9ec03e240add280cb3...461ef6c76dfe95d5c364de2f431ddbd31a417628)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f8f80d7`](https://github.com/OZI-Project/ozi-templates/commit/f8f80d7b0c04cd8ba5edf83cee5fd1299b6903ad))

*  Bump github/codeql-action from 3.26.7 to 3.26.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.7 to 3.26.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8214744c546c1e5c8f03dde8fab3a7353211988d...294a9d92911152fe08befb9ec03e240add280cb3)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c4f46d2`](https://github.com/OZI-Project/ozi-templates/commit/c4f46d23c820432fae72ecd0d808e7a4dd0f7637))


### Other


* Update ozi.wrap — Eden Ross Duff, MSc, DDiv <rjdbcm@outlook.com>
([`afbc3ee`](https://github.com/OZI-Project/ozi-templates/commit/afbc3ee5e6534f8abca1bd01e76c7914e0d29d0a))

## 2.12.1 (2024-09-17)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.6 to 3.26.7

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.6 to 3.26.7.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4dd16135b69a43b6c8efb853346f8437d92d3c93...8214744c546c1e5c8f03dde8fab3a7353211988d)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8e2703a`](https://github.com/OZI-Project/ozi-templates/commit/8e2703a6f1bb8872daba54f29ac5bfbfbd98bad3))


### Other


* fix: broken generator in LICENSE template — rjdbcm <rjdbcm@outlook.com>
([`6dd601e`](https://github.com/OZI-Project/ozi-templates/commit/6dd601e173bba51a717867b6467b4dad442bb443))

## 2.12.0 (2024-09-15)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.9.1 to 2.10.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.1 to 2.10.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde...91182cccc01eb5e619899d80e4e971d6181294a7)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`d34e81c`](https://github.com/OZI-Project/ozi-templates/commit/d34e81c05c67f86e97ef73b93ccf072919937ff6))


### ✨ Implemented Features

* 🔨: add support for license exception rendering — rjdbcm <rjdbcm@outlook.com>
([`a9f95b2`](https://github.com/OZI-Project/ozi-templates/commit/a9f95b25e94e4caa8d72ac0a1d190c6d34792164))

## 2.11.1 (2024-09-10)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/checkpoint from 0.5.2 to 1.0.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.2 to 1.0.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.2...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`dcf8ab6`](https://github.com/OZI-Project/ozi-templates/commit/dcf8ab6b63e7b81b0a90fc51f198a5f3604e5b81))

*  Bump OZI-Project/release from 0.8.11 to 1.0.0

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/4277e29de16b07dac4a89c8f7970c2da65554d17...98248899bb8b235e3198105f080093ea5b9751d8)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`443152b`](https://github.com/OZI-Project/ozi-templates/commit/443152b55d0f3dbd936db85493bf2464f3a67c4b))

*  Bump OZI-Project/publish from 0.1.11 to 1.0.0

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`aabc85f`](https://github.com/OZI-Project/ozi-templates/commit/aabc85f72f815d94038281e09a8b3a55f528ba0b))

*  Bump OZI-Project/draft from 0.3.11 to 1.0.0

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.11 to 1.0.0.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.11...1.0.0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] <support@github.com>
([`d721c8a`](https://github.com/OZI-Project/ozi-templates/commit/d721c8a33f63f16d6f93907b195a3a008683e8bf))


### Other


* [StepSecurity] Apply security best practices — StepSecurity Bot <bot@stepsecurity.io>
([`fa94694`](https://github.com/OZI-Project/ozi-templates/commit/fa94694bf7c816c57815b856f706d7f2a75b686e))

* 👷(github_workflows): add endpoints used by self-hosted CI for posterity — rjdbcm <rjdbcm@outlook.com>
([`4c103aa`](https://github.com/OZI-Project/ozi-templates/commit/4c103aa4d4da13e122ef13bb6767a93452260835))

## 2.11.0 (2024-09-08)


### ✨ Implemented Features

*  remove the compound pyproject.toml:project.optional-dependencies key ``dev``

This improves CI provider dependency introspection compatibility. — rjdbcm <rjdbcm@outlook.com>
([`5c47596`](https://github.com/OZI-Project/ozi-templates/commit/5c47596fcc775728d2383094b0c349b60a7c34de))

* (root.pyproject.toml): remove ``dynamic = ["version"]`` — rjdbcm <rjdbcm@outlook.com>
([`e3170df`](https://github.com/OZI-Project/ozi-templates/commit/e3170df4746cd9fb1c131918741544b467b7f9b2))

## 2.10.3 (2024-09-07)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.6 to 4.4.0

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.6 to 4.4.0.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/834a144ee995460fba8ed112a2fc961b36a5ec5a...50769540e7f4bd5e21e526ee35c689e35e0d6874)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1da1d37`](https://github.com/OZI-Project/ozi-templates/commit/1da1d376f12524d16998154181beb4603850def5))

*  Bump OZI-Project/publish from 0.1.10 to 0.1.11

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.10 to 0.1.11.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.10...0.1.11)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`627aed4`](https://github.com/OZI-Project/ozi-templates/commit/627aed42eaf38f29a111dfe45578adb38de2623f))

*  Bump OZI-Project/release from 0.8.10 to 0.8.11

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.10 to 0.8.11.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22...4277e29de16b07dac4a89c8f7970c2da65554d17)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5d809d3`](https://github.com/OZI-Project/ozi-templates/commit/5d809d36b401f92d85615bbb69710dcf466bd27d))

*  Bump OZI-Project/draft from 0.3.9 to 0.3.11

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.9 to 0.3.11.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.9...0.3.11)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b292df4`](https://github.com/OZI-Project/ozi-templates/commit/b292df46155ae5138f8c8eefdab02c223dcb169d))

## 2.10.2 (2024-08-31)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.4 to 3.26.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.4 to 3.26.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f0f3afee809481da311ca3a6ff1ff51d81dbeb24...4dd16135b69a43b6c8efb853346f8437d92d3c93)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`5de7472`](https://github.com/OZI-Project/ozi-templates/commit/5de747218dfce585bcfe833a2680117c237c6978))


### 🔨 Updated Scripts

*  Update ozi.wrap — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`68e8046`](https://github.com/OZI-Project/ozi-templates/commit/68e80460ee306a3c96a888b7e7cbc6078e655225))

## 2.10.1 (2024-08-29)


### 🐛 Fixed Bugs

*  add description-file — rjdbcm <rjdbcm@outlook.com>
([`197a493`](https://github.com/OZI-Project/ozi-templates/commit/197a493f7aeb8c4f80509c4063ad50e19e5813c9))

*  fix deps install check — rjdbcm <rjdbcm@outlook.com>
([`abd1c64`](https://github.com/OZI-Project/ozi-templates/commit/abd1c641e31d313827a53d81e05504067b0f2c3e))

*  fixes for OZI 1.20 build changes — rjdbcm <rjdbcm@outlook.com>
([`81ff9a3`](https://github.com/OZI-Project/ozi-templates/commit/81ff9a338cdd331263dd01932cb6fd4f0753a0fa))

*  add length() check to deps install
([`deb25e5`](https://github.com/OZI-Project/ozi-templates/commit/deb25e5d57b6dd6858df1f6bd88633166e76a8e0))

*  add length() check to deps install — rjdbcm <rjdbcm@outlook.com>
([`ed6ba07`](https://github.com/OZI-Project/ozi-templates/commit/ed6ba070360679fd1dd0a1a2712e925f52b1cf51))

*  add project.dependencies install — rjdbcm <rjdbcm@outlook.com>
([`6e3c841`](https://github.com/OZI-Project/ozi-templates/commit/6e3c84159c6a3afb7c9a0bb637ac17b94ac5f7be))

*  fixes for OZI 1.20
([`1c7d0b7`](https://github.com/OZI-Project/ozi-templates/commit/1c7d0b7749b13656ce6d828fc03609bcd5f06e76))

## 2.10.0 (2024-08-28)


### ✨ Implemented Features

*  ozi-spec 0.9 and OZI.build 1.3 — rjdbcm <rjdbcm@outlook.com>
([`ef3ac79`](https://github.com/OZI-Project/ozi-templates/commit/ef3ac798eef248228461d2310dc4df1c8efe7ade))

## 2.9.3 (2024-08-23)


### 🐛 Fixed Bugs

*  fix ozi options in tox setup — rjdbcm <rjdbcm@outlook.com>
([`d2ce4e6`](https://github.com/OZI-Project/ozi-templates/commit/d2ce4e6e913f22d24c4dc0902cf860b1f2d37ca3))

## 2.9.2 (2024-08-23)


### 🐛 Fixed Bugs

*  fix string quote for build-system deps
([`c0f496f`](https://github.com/OZI-Project/ozi-templates/commit/c0f496fa525367bd4474d40630b2c732c1906370))

* ✏️ fix OZI.build extras rendering — rjdbcm <rjdbcm@outlook.com>
([`08f50d0`](https://github.com/OZI-Project/ozi-templates/commit/08f50d0226b46617a7ca3a056f76bb9a9f6d3c6b))

## 2.9.1 (2024-08-23)


### 🐛 Fixed Bugs

*  add asyncio_default_fixture_loop_scope="function" to pytest setup — rjdbcm <rjdbcm@outlook.com>
([`ab166c6`](https://github.com/OZI-Project/ozi-templates/commit/ab166c671538b2d29dbe976c70d32ef3a74ff932))

## 2.9.0 (2024-08-22)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`d269c50`](https://github.com/OZI-Project/ozi-templates/commit/d269c5028d6d902592d69380736789f7255362c6))

*  Bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b3aa25d`](https://github.com/OZI-Project/ozi-templates/commit/b3aa25d0a9a75496d35259e58c85283115067a77))

*  Bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f4172eb60419c98b5cf18c89d78cde8b553f5d15...7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ad95a4c`](https://github.com/OZI-Project/ozi-templates/commit/ad95a4c15700fce190a95eeb88e17784b53d13db))

*  Bump github/codeql-action from 3.26.2 to 3.26.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.2 to 3.26.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/429e1977040da7a23b6822b13c129cd1ba93dbb2...f0f3afee809481da311ca3a6ff1ff51d81dbeb24)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`7aae05e`](https://github.com/OZI-Project/ozi-templates/commit/7aae05e71655c12697439ec94b451d5d726c27b8))

*  Bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`72f3f10`](https://github.com/OZI-Project/ozi-templates/commit/72f3f10c2c98a7b3363a0e67e62a8e12b8bd8012))


### ✨ Implemented Features

*  update for OZI spec 0.8

Simplified build-system requires using OZI.build 1.2 — rjdbcm <rjdbcm@outlook.com>
([`feb6b07`](https://github.com/OZI-Project/ozi-templates/commit/feb6b075c1a76f265432d63a980cc7de6adc1af8))

## 2.8.2 (2024-08-18)


### 🐛 Fixed Bugs

* ✏️ use whole compile-requirements-command array — rjdbcm <rjdbcm@outlook.com>
([`cd15dda`](https://github.com/OZI-Project/ozi-templates/commit/cd15dda8487ab702aff43cc72d7c03660b9d6e10))

## 2.8.1 (2024-08-18)


### 🐛 Fixed Bugs

*  fix compile requirements command finding — rjdbcm <rjdbcm@outlook.com>
([`3a57da2`](https://github.com/OZI-Project/ozi-templates/commit/3a57da220276c804482be42a30f9592a4ed9269a))

## 2.8.0 (2024-08-16)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.1 to 3.26.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.1 to 3.26.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/29d86d22a34ea372b1bbf3b2dced2e25ca6b3384...429e1977040da7a23b6822b13c129cd1ba93dbb2)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e5b620c`](https://github.com/OZI-Project/ozi-templates/commit/e5b620c061b3256511de2e2c72821af6488484a3))


### 🔨 Updated Scripts

*  expect ``project.enable_uv`` boolean — rjdbcm <rjdbcm@outlook.com>
([`5874996`](https://github.com/OZI-Project/ozi-templates/commit/58749961b3f1eb0005ca6aed697f505299d8d3c4))


### ✨ Implemented Features

* 🔨 add cibuildwheel config template — rjdbcm <rjdbcm@outlook.com>
([`180cefd`](https://github.com/OZI-Project/ozi-templates/commit/180cefde57a11af559c141e0a2685a7e0040dea5))

## 2.7.1 (2024-08-15)


### 🐛 Fixed Bugs

*  fix tox invoke path and options — rjdbcm <rjdbcm@outlook.com>
([`c9d72a2`](https://github.com/OZI-Project/ozi-templates/commit/c9d72a2785b9cf8877bf9524bf1654f9b8099cde))

## 2.7.0 (2024-08-15)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.0 to 3.26.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.0 to 3.26.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/eb055d739abdc2e8de2e5f4ba1a8b246daa779aa...29d86d22a34ea372b1bbf3b2dced2e25ca6b3384)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`69a67a9`](https://github.com/OZI-Project/ozi-templates/commit/69a67a9aeedc9f484c002bb9f3601125a8d1debe))

*  Bump OZI-Project/release from 0.8.7 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.7 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/3280088d580a25abdecd35ebb022d4529af6a995...f4172eb60419c98b5cf18c89d78cde8b553f5d15)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8ced9a8`](https://github.com/OZI-Project/ozi-templates/commit/8ced9a887472a40d9b25754778a48512bc5862f8))

*  Bump OZI-Project/release from 0.8.4 to 0.8.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.4 to 0.8.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0ca87b5495c672f0d0c5ceaa6508e631a5c051f9...3280088d580a25abdecd35ebb022d4529af6a995)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b246ad2`](https://github.com/OZI-Project/ozi-templates/commit/b246ad2484ce8233affade7aa72eed0ff6cf7125))


### ✨ Implemented Features

*  add expectation for project namespace to set ``--github-harden-runner`` — rjdbcm <rjdbcm@outlook.com>
([`8489091`](https://github.com/OZI-Project/ozi-templates/commit/8489091eb78ae90aea1e8546e0e152feb0446f79))

*  add ``tox -e invoke [release|publish]`` template for local CI/CD — rjdbcm <rjdbcm@outlook.com>
([`b743496`](https://github.com/OZI-Project/ozi-templates/commit/b74349603e5e072b30c61a59523b37b9da205820))

## 2.6.4 (2024-08-09)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release@0.8.4 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`61f7c88`](https://github.com/OZI-Project/ozi-templates/commit/61f7c881b4e6d2d3905f6b374251c665ce245d07))

## 2.6.3 (2024-08-09)


### 🔨 Updated Scripts

*  Update ozi.yml:release endpoint allow list for 0.8.x — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`5f7e9ad`](https://github.com/OZI-Project/ozi-templates/commit/5f7e9ad22a0534809630313e20ab1a4d4c0d28f6))

## 2.6.2 (2024-08-09)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.15 to 3.26.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.15 to 3.26.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/afb54ba388a7dca6ecae48f608c4ff05ff4cc77a...eb055d739abdc2e8de2e5f4ba1a8b246daa779aa)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`561f5f3`](https://github.com/OZI-Project/ozi-templates/commit/561f5f3ee9c340398d0647b6e5533b7c9519c02f))

*  Bump actions/upload-artifact from 4.3.5 to 4.3.6

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.5 to 4.3.6.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/89ef406dd8d7e03cfd12d9e0a4a378f454709029...834a144ee995460fba8ed112a2fc961b36a5ec5a)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9df90ef`](https://github.com/OZI-Project/ozi-templates/commit/9df90efbdc619b4cf160e890fa327dc3a0139277))

*  Bump OZI-Project/release from 0.7.4 to 0.8.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`e58783f`](https://github.com/OZI-Project/ozi-templates/commit/e58783f46a7e845042e2b0ee8917aa3cab5e6797))

## 2.6.1 (2024-08-07)


### 🚸 Improved Usability

*  add python 3.13 to supported versions

note that this support is untested — rjdbcm <rjdbcm@outlook.com>
([`61d5329`](https://github.com/OZI-Project/ozi-templates/commit/61d532907dd59d22e36344582997b30830b06454))

## 2.6.0 (2024-08-07)


### 🔥 Deleted Code or Files

*  remove ``filter.sha256sum`` — rjdbcm <rjdbcm@outlook.com>
([`6aa7c08`](https://github.com/OZI-Project/ozi-templates/commit/6aa7c08686e11b3789d407c7d8bd5d40a0bd2f70))


### ➖ Removed Dependencies

*  requests — rjdbcm <rjdbcm@outlook.com>
([`2b6e389`](https://github.com/OZI-Project/ozi-templates/commit/2b6e3899d166cbfddd86f54c050623b889ccea4f))


### ✏️ Corrected Typos

*  remove requests import — rjdbcm <rjdbcm@outlook.com>
([`08243ed`](https://github.com/OZI-Project/ozi-templates/commit/08243ede0041279740958e0e0f87500acc43fd00))


### ✨ Implemented Features

*  beta release — rjdbcm <rjdbcm@outlook.com>
([`b78eb85`](https://github.com/OZI-Project/ozi-templates/commit/b78eb851053fe7f684725cbec629fe9305b86458))

## 2.5.8 (2024-08-05)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e381013`](https://github.com/OZI-Project/ozi-templates/commit/e381013ccbbfa044b4bf12a8ae94a3e7632685bb))

*  Bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4ff93ff`](https://github.com/OZI-Project/ozi-templates/commit/4ff93ffdadc3f7b2d3fd82c3f25c3e57e78b6824))

*  Bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ea8786d`](https://github.com/OZI-Project/ozi-templates/commit/ea8786d5489d126254168e01254fdf5c30436785))

*  Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`fe105e3`](https://github.com/OZI-Project/ozi-templates/commit/fe105e3ab418f7ed9d60507413c7f4f6e7018261))

## 2.5.7 (2024-08-05)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.4 to 4.3.5

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/0b2256b8c012f0828dc542b3febcab082c67f72b...89ef406dd8d7e03cfd12d9e0a4a378f454709029)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`8050f7e`](https://github.com/OZI-Project/ozi-templates/commit/8050f7edb56a9a5c15c9e3a900057733e29f8b90))

*  Bump ossf/scorecard-action from 2.3.3 to 2.4.0

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.3 to 2.4.0.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/dc50aa9510b46c811795eb24b2f1ba02a914e534...62b2cac7ed8198b15735ed49ab1e5cf35480ba46)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`a48a841`](https://github.com/OZI-Project/ozi-templates/commit/a48a841dc940323a4fada32d01e659b1edd14723))

*  Bump github/codeql-action from 3.25.14 to 3.25.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.14 to 3.25.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5cf07d8b700b67e235fbb65cbc84f69c0cf10464...afb54ba388a7dca6ecae48f608c4ff05ff4cc77a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`f3fd7a3`](https://github.com/OZI-Project/ozi-templates/commit/f3fd7a377e6a1cbcf822277648188ac3a4df78d0))


### Other


* perf: Update dependabot.yml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`d1d8d5c`](https://github.com/OZI-Project/ozi-templates/commit/d1d8d5c69984b3ec8975c58cfc0c003856c12473))

## 2.5.6 (2024-07-28)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e8d483d`](https://github.com/OZI-Project/ozi-templates/commit/e8d483da7b8c0bab1656d321126683b36549d3d7))

*  Bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`defebd0`](https://github.com/OZI-Project/ozi-templates/commit/defebd0ffcae9dd741aa347c1327308f1cb2648c))

*  Bump github/codeql-action from 3.25.13 to 3.25.14

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.13 to 3.25.14.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2d790406f505036ef40ecba973cc774a50395aac...5cf07d8b700b67e235fbb65cbc84f69c0cf10464)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c71cd07`](https://github.com/OZI-Project/ozi-templates/commit/c71cd077fe815fafdc75580daf10a4b02d7ac742))

*  Bump github/codeql-action from 3.25.12 to 3.25.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.12 to 3.25.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4fa2a7953630fd2f3fb380f21be14ede0169dd4f...2d790406f505036ef40ecba973cc774a50395aac)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`4e709c7`](https://github.com/OZI-Project/ozi-templates/commit/4e709c70ac5c53464e8b44089d26b9fe1419a2e9))


### Other


* feat: use ``ozi.version`` as key for wrapfile revision — rjdbcm <rjdbcm@outlook.com>
([`e1861b6`](https://github.com/OZI-Project/ozi-templates/commit/e1861b647294da22aafb9b0a76b889560ea9906a))

## 2.5.5 (2024-07-18)

## 2.5.4 (2024-07-18)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.8.1 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.1 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`66de119`](https://github.com/OZI-Project/ozi-templates/commit/66de119380298fdc9b9fc0995e2901170037b371))

*  Bump OZI-Project/checkpoint from 0.4.3 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.3 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.3...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`ffa7fed`](https://github.com/OZI-Project/ozi-templates/commit/ffa7fed787340d778c7dea479923b0ab313014df))

*  Bump OZI-Project/release from 0.6.6 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.6 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.6...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`40c39f6`](https://github.com/OZI-Project/ozi-templates/commit/40c39f64486d80886fd059ad3901a61de442ec9a))

*  Bump OZI-Project/draft from 0.3.5 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.5 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.5...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`00ed822`](https://github.com/OZI-Project/ozi-templates/commit/00ed822acc63f36c3f62eb553dda180c24a0945f))


### 📌 Pinned Dependencies

*  OZI.build>=0.0.27 — rjdbcm <rjdbcm@outlook.com>
([`aec9c2e`](https://github.com/OZI-Project/ozi-templates/commit/aec9c2e1d32ddda1df2a63f574302239579aa998))

## 2.5.3 (2024-07-15)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.6.5 to 0.6.6

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.6.6.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.6.6)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`09bba10`](https://github.com/OZI-Project/ozi-templates/commit/09bba108706c0a37c13ba51ef1873b7ea83a91b9))

*  Bump OZI-Project/checkpoint from 0.4.2 to 0.4.3

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.4.3.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.4.3)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`95c0d15`](https://github.com/OZI-Project/ozi-templates/commit/95c0d15899ba8e7fd04ccdc98bdf021213b159e0))

*  Bump OZI-Project/draft from 0.3.4 to 0.3.5

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.4 to 0.3.5.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.4...0.3.5)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`1027de3`](https://github.com/OZI-Project/ozi-templates/commit/1027de31f885adfaec3c1ff7b65b26bc3d80fc98))

*  Bump OZI-Project/publish from 0.1.7 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.7 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.7...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`9446b32`](https://github.com/OZI-Project/ozi-templates/commit/9446b32d93d4cf276d7ebb576c09de1729d081a0))

*  Bump actions/dependency-review-action from 4.3.3 to 4.3.4

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/72eb03d02c7872a771aacd928f3123ac62ad6d3a...5a2ce3f5b92ee19cbb1541a4984c76d921601d7c)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`77bc3af`](https://github.com/OZI-Project/ozi-templates/commit/77bc3af4418b26fd052ad461c422b7ab26d15fec))

*  Bump github/codeql-action from 3.25.11 to 3.25.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.11 to 3.25.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b611370bb5703a7efb587f9d136a52ea24c5c38c...4fa2a7953630fd2f3fb380f21be14ede0169dd4f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`002ccd5`](https://github.com/OZI-Project/ozi-templates/commit/002ccd5adc2b5f4c2a22dbdea69cc16ad5d6b70b))

## 2.5.2 (2024-07-08)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.3 to 0.3.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.3...0.3.4)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`e07446b`](https://github.com/OZI-Project/ozi-templates/commit/e07446bdc7d4a5834e604757b93705743c6e14eb))

*  Bump OZI-Project/publish from 0.1.6 to 0.1.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.6...0.1.7)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b770bf8`](https://github.com/OZI-Project/ozi-templates/commit/b770bf8cc08fe44fa18ac9b6850f94572903c55a))

*  Bump actions/upload-artifact from 4.3.3 to 4.3.4

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65462800fd760344b1a7b4382951275a0abb4808...0b2256b8c012f0828dc542b3febcab082c67f72b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`c673007`](https://github.com/OZI-Project/ozi-templates/commit/c673007c378d69e346a6c4a028b2a75843a80220))

## 2.5.1 (2024-07-08)


### 🐛 Fixed Bugs

* add subprojects templates to build — rjdbcm <rjdbcm@outlook.com>
([`c7d229d`](https://github.com/OZI-Project/ozi-templates/commit/c7d229dcc9cf63dd29dab0ff927cac8107a9d55a))

## 2.5.0 (2024-07-07)


### ✨ Implemented Features

*  update for OZI spec 0.5 — rjdbcm <rjdbcm@outlook.com>
([`6363eaa`](https://github.com/OZI-Project/ozi-templates/commit/6363eaa0b3c35f3519add1b2f2cf37e2a283e85d))

## 2.4.9 (2024-07-04)


### 🚸 Improved Usability

*  add release pattern matching default OZI workflow to semantic_release config template — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`0351743`](https://github.com/OZI-Project/ozi-templates/commit/035174311c70af5986c96d1ce188d620b904ab04))

## 2.4.8 (2024-07-03)


### 🐛 Fixed Bugs

*  release patch fixes for names
([`790e648`](https://github.com/OZI-Project/ozi-templates/commit/790e648971a020f2c71095efdfae7ea5a5da7e70))


### Other


* fix: Non-lowercase and underscored name expected for ``project.name`` context — rjdbcm <rjdbcm@outlook.com>
([`e9feb82`](https://github.com/OZI-Project/ozi-templates/commit/e9feb82ded67eed301cc4b022ad09f82cb8c17a7))

* fix(CHANGELOG): add project name to heading

release
([`fb7dcb3`](https://github.com/OZI-Project/ozi-templates/commit/fb7dcb3ddbb64172ce989fa0790f891c152f1f41))

## 2.4.7 (2024-07-03)


### 🐛 Fixed Bugs

*  consistent CHANGELOG style, initial 0.0.0 entry no longer overwritten by semantic-release — rjdbcm <rjdbcm@outlook.com>
([`c42b863`](https://github.com/OZI-Project/ozi-templates/commit/c42b8634343566fe3ab633ffa789f04a1ec1cf0f))


### Other


* Update CHANGELOG.md.j2 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`727eb6c`](https://github.com/OZI-Project/ozi-templates/commit/727eb6ce0ead15df9202a6a8a30c642762b5b3b1))

## 2.4.6 (2024-07-03)


### 🐛 Fixed Bugs

*  fix duplicated changelog commit headings — rjdbcm <rjdbcm@outlook.com>
([`4e04403`](https://github.com/OZI-Project/ozi-templates/commit/4e04403ae80ac37cc64f4b9550fe292b81b661cd))

## 2.4.5 (2024-07-03)


### 🐛 Fixed Bugs

*  fix requirements.in render to properly ignore newlines — rjdbcm <rjdbcm@outlook.com>
([`2e04d1a`](https://github.com/OZI-Project/ozi-templates/commit/2e04d1a99bf41b732246896211b08dccfdafb6d1))


### 🚸 Improved Usability

*  remove CHANGELOG.md from build files — rjdbcm <rjdbcm@outlook.com>
([`b5a89ae`](https://github.com/OZI-Project/ozi-templates/commit/b5a89ae32d5c6c12188e2f7306a359cdef358599))

## 2.4.4 (2024-07-03)


### 🐛 Fixed Bugs

*  fix nesting issue in CHANGELOG template — rjdbcm <rjdbcm@outlook.com>
([`92a1954`](https://github.com/OZI-Project/ozi-templates/commit/92a1954eaa44197112abbd8760836b068849bd49))

*  fix changelog template
([`2c0936c`](https://github.com/OZI-Project/ozi-templates/commit/2c0936c9c8e1fda135acf5ceeafb8fc3f4a9b402))


### Other


* Update CHANGELOG.md.j2 — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`ae69e8d`](https://github.com/OZI-Project/ozi-templates/commit/ae69e8d6df037bd2101879111f3159fd63d7c447))

## 2.4.3 (2024-07-03)


### 🐛 Fixed Bugs

*  escape raw jinja2 in changelog template — rjdbcm <rjdbcm@outlook.com>
([`3473956`](https://github.com/OZI-Project/ozi-templates/commit/347395685a96db7d5beef7a678fa57e668b0a6d4))

## 2.4.2 (2024-07-02)


### 🚸 Improved Usability

* Update ``CHANGELOG.md.j2`` to replace gitmoji codes with unicode characters. — rjdbcm <rjdbcm@outlook.com>
([`afa3f4d`](https://github.com/OZI-Project/ozi-templates/commit/afa3f4d9cc32170cfa297cb80ea21c48353578b1))

## 2.4.1 (2024-07-02)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.10 to 3.25.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.10 to 3.25.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/23acc5c183826b7a8a97bce3cecc52db901f8251...b611370bb5703a7efb587f9d136a52ea24c5c38c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`84906bf`](https://github.com/OZI-Project/ozi-templates/commit/84906bf6a063545bac2567d810abc036918ecad9))


### 🚸 Improved Usability

* (license): add BlueOak-1.0.0 templates — rjdbcm <rjdbcm@outlook.com>
([`888f02d`](https://github.com/OZI-Project/ozi-templates/commit/888f02d18a1297413b0ece695508aea549d80106))

## 2.4.0 (2024-07-01)


### ✨ Implemented Features

* (license): add CeCILL-B, CeCILL-C, MirOS, OGTSL, and UPL-1.0 support.

Also fixes unlicense. — rjdbcm <rjdbcm@outlook.com>
([`334da31`](https://github.com/OZI-Project/ozi-templates/commit/334da31a55bc845dfddbebde1f5acc635057a66c))

## 2.3.4 (2024-06-30)


### 🐛 Fixed Bugs

*  fix missing unlicense — rjdbcm <rjdbcm@outlook.com>
([`eed9ec6`](https://github.com/OZI-Project/ozi-templates/commit/eed9ec690af111fc439d2f46bdf60f1a65f20492))

## 2.3.3 (2024-06-30)


### 🐛 Fixed Bugs

*  fix missing Eiffel and 0BSD license folders — rjdbcm <rjdbcm@outlook.com>
([`ca1ca00`](https://github.com/OZI-Project/ozi-templates/commit/ca1ca0094577a5b605a2c3b418090c91d1f671d0))

## 2.3.2 (2024-06-29)


### 🐛 Fixed Bugs

*  add missing Eiffel_Forum_License__EFL_ folder to install — rjdbcm <rjdbcm@outlook.com>
([`f129ef2`](https://github.com/OZI-Project/ozi-templates/commit/f129ef236951d1875d7d608681f7ca39f1b3bfde))

## 2.3.1 (2024-06-29)


### 🐛 Fixed Bugs

*  add missing EFL licenses — rjdbcm <rjdbcm@outlook.com>
([`f0fb24e`](https://github.com/OZI-Project/ozi-templates/commit/f0fb24e0146e741d0f2f43871b3a58c91e6cce87))

## 2.3.0 (2024-06-29)


### ✏️ Corrected Typos

*  missed comma — rjdbcm <rjdbcm@outlook.com>
([`59c1242`](https://github.com/OZI-Project/ozi-templates/commit/59c124291c7db9bae8c5485763ffad1dea636cba))


### ✨ Implemented Features

* (license) add all supported license variants — rjdbcm <rjdbcm@outlook.com>
([`2927fa1`](https://github.com/OZI-Project/ozi-templates/commit/2927fa1db28dcc63c7893aae6ee199008279bd12))

## 2.2.0 (2024-06-28)


### 🐛 Fixed Bugs

*  add ``OSI Approved :: ... Unlicense ...`` templates. — rjdbcm <rjdbcm@outlook.com>
([`4ec65b7`](https://github.com/OZI-Project/ozi-templates/commit/4ec65b70ddbe40717bab358c414a285b0f260249))


### ✨ Implemented Features

*  default to Unlicense for LicenseRef-Public-Domain — rjdbcm <rjdbcm@outlook.com>
([`14b469f`](https://github.com/OZI-Project/ozi-templates/commit/14b469fa5bbcf21ff4eccfa70c1a20899a416dca))

## 2.1.2 (2024-06-21)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.2 to 0.3.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.2 to 0.3.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.2...0.3.3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`dec807f`](https://github.com/OZI-Project/ozi-templates/commit/dec807ff39d8b2438bc837c397e0f050cc0b4101))

*  Bump OZI-Project/publish from 0.1.5 to 0.1.6

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.5...0.1.6)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`3fe734d`](https://github.com/OZI-Project/ozi-templates/commit/3fe734d2ab68217309461dae0f6bdf462bdcc88a))


### 🐛 Fixed Bugs

*  parsed_commit_heading renamed to avoid rendering — rjdbcm <rjdbcm@outlook.com>
([`9a8b8e1`](https://github.com/OZI-Project/ozi-templates/commit/9a8b8e17e31c6874da9be3ac82007d26db95efaa))

## 2.1.1 (2024-06-20)


### 🐛 Fixed Bugs

*  escape CHANGELOG and release notes templates — rjdbcm <rjdbcm@outlook.com>
([`4546e4e`](https://github.com/OZI-Project/ozi-templates/commit/4546e4e889b257bfd4fe861a1ebe6936929fe818))

## 2.1.0 (2024-06-20)


### 🐛 Fixed Bugs

* 📝 fix double escape in changelog — rjdbcm <rjdbcm@outlook.com>
([`a820edd`](https://github.com/OZI-Project/ozi-templates/commit/a820edd95fbea12c4c0be5198f474d07eb42f0d2))


### ✨ Implemented Features

*  add templates folder to build

The following templates are used by semantic-release:
- ``CHANGELOG.md.j2``
- ``.release_notes.md.j2``

``parsed_commit_heading.j2`` is included in both to render common commit headings. — rjdbcm <rjdbcm@outlook.com>
([`fff61a8`](https://github.com/OZI-Project/ozi-templates/commit/fff61a8e5279e1905c1fc104c53f3f53a4069220))

## 2.0.8 (2024-06-20)


### 🐛 Fixed Bugs

*  update wrap address in template to OZI-Project — rjdbcm <rjdbcm@outlook.com>
([`030351d`](https://github.com/OZI-Project/ozi-templates/commit/030351d8197881b454007790c237503e3478d58a))


### Other


* 📝 update CHANGELOG and release notes templates — rjdbcm <rjdbcm@outlook.com>
([`26f02d0`](https://github.com/OZI-Project/ozi-templates/commit/26f02d078ce6ad4874f97c0cba16aa9ee382930d))

## 2.0.7 (2024-06-18)


### 🚸 Improved Usability

* CHANGELOG and release_notes templates — rjdbcm <rjdbcm@outlook.com>
([`fa3ebef`](https://github.com/OZI-Project/ozi-templates/commit/fa3ebefbb148b70150f26f90e90aff274df66178))

## 2.0.6 (2024-06-17)


### 🐛 Fixed Bugs

* (checkpoint.yml.j2): prerelease checkpoint no longer included by default — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`124bc74`](https://github.com/OZI-Project/ozi-templates/commit/124bc741ca57781492785fab45d6712eee0a2fd5))


### 🚸 Improved Usability

*  Create .gitattributes — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`cf0ba23`](https://github.com/OZI-Project/ozi-templates/commit/cf0ba231f2e911dccf5696c9d5749cc00052f346))

## 2.0.5 (2024-06-17)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.1 to 0.3.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.1 to 0.3.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.1...0.3.2)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`68a5674`](https://github.com/OZI-Project/ozi-templates/commit/68a56749f240cd2a18f42c9f7bb1e8907c1b240f))

*  Bump github/codeql-action from 3.25.3 to 3.25.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.3 to 3.25.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d39d31e687223d841ef683f52467bd88e9b21c14...23acc5c183826b7a8a97bce3cecc52db901f8251)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`ff5472f`](https://github.com/OZI-Project/ozi-templates/commit/ff5472f9f2b8d10b48bdd4c1fe061da15699e1fe))

*  Bump ossf/scorecard-action from 2.3.1 to 2.3.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.1 to 2.3.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/0864cf19026789058feabb7e87baa5f140aac736...dc50aa9510b46c811795eb24b2f1ba02a914e534)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`b8cc5cf`](https://github.com/OZI-Project/ozi-templates/commit/b8cc5cffb37316b48d63120564e0b4aca5224203))

*  Bump actions/dependency-review-action from 4.2.5 to 4.3.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.2.5 to 4.3.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5bbc3ba658137598168acb2ab73b21c432dd411b...72eb03d02c7872a771aacd928f3123ac62ad6d3a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`c1498bd`](https://github.com/OZI-Project/ozi-templates/commit/c1498bd797c36a2b03e5dc8a0f7adc5145425f21))

*  Bump step-security/harden-runner from 2.7.0 to 2.8.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.0 to 2.8.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/63c24ba6bd7ba022e95695ff85de572c04a18142...17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`bbc592e`](https://github.com/OZI-Project/ozi-templates/commit/bbc592eb025bdd61ee5003bd554b1f5c04b61702))

*  Bump OZI-Project/checkpoint from 0.1.5 to 0.4.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.5 to 0.4.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.1.5...0.4.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] <support@github.com>
([`1ad4dd1`](https://github.com/OZI-Project/ozi-templates/commit/1ad4dd1b02e628b79366f6da2e582bb7ed660dc8))

*  Bump actions/checkout from 4.1.4 to 4.1.7

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.4 to 4.1.7.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/0ad4b8fadaa221de15dcec353f45205ec38ea70b...692973e3d937129bcbf40652eb9f2f61becf3332)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`282d6b9`](https://github.com/OZI-Project/ozi-templates/commit/282d6b96d026d2285e7699169813d853715531d1))

## 2.0.4 (2024-06-17)


### 🐛 Fixed Bugs

*  fix PackageLoader path — rjdbcm <rjdbcm@outlook.com>
([`888050d`](https://github.com/OZI-Project/ozi-templates/commit/888050d270d1ac02ba684ee837b3347d2f2cf310))

## 2.0.3 (2024-06-17)


### 🐛 Fixed Bugs

*  fix blastpipe reference in packageloader — rjdbcm <rjdbcm@outlook.com>
([`2be3d1a`](https://github.com/OZI-Project/ozi-templates/commit/2be3d1a98cd266f85f5fb8e464dc10112f091e27))

## 2.0.2 (2024-06-16)


### 🐛 Fixed Bugs

*  fix project module name
([`03f8b1e`](https://github.com/OZI-Project/ozi-templates/commit/03f8b1e630ebf02f513877248ac351436a047c15))

## 2.0.1 (2024-06-16)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release@0.6.5

Ignores wheel filenames in glob for sigstore. — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`bbe482d`](https://github.com/OZI-Project/ozi-templates/commit/bbe482da512ab78ea4c3ebcdc92a925f4e0525df))

*  bump OZI.build
([`843f161`](https://github.com/OZI-Project/ozi-templates/commit/843f161073077b5bfafcd4f052f9055e256182a2))


### 🐛 Fixed Bugs

*  OZI.build>=0.0.26

parity with blastpipe 2024.11.10 — rjdbcm <rjdbcm@outlook.com>
([`b57d4f6`](https://github.com/OZI-Project/ozi-templates/commit/b57d4f67aa1622ddb98ab89540b063f4924a1927))

*  project name
([`1aba880`](https://github.com/OZI-Project/ozi-templates/commit/1aba8809cef1d70bc97ff9497c65cad7b5466242))


### Other


* Update README — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`3efec29`](https://github.com/OZI-Project/ozi-templates/commit/3efec29e2c5efdd4745e202c631649b92f62b049))

* Update meson.build - fix project name — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`95719bf`](https://github.com/OZI-Project/ozi-templates/commit/95719bf0abdee4f4dc7c74a332d115868bf76c3a))

* Fix branch pattern — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`d221e61`](https://github.com/OZI-Project/ozi-templates/commit/d221e618bca32cdf51c7dd26bb58376825d0a05b))

## 2.0.0 (2024-06-16)


### 💥


*  version bump — rjdbcm <rjdbcm@outlook.com>
([`52b4953`](https://github.com/OZI-Project/ozi-templates/commit/52b4953eaaf9427636b4112f5f7378678b2b0a50))

*  fix release strategy
([`e40ebfb`](https://github.com/OZI-Project/ozi-templates/commit/e40ebfb305a64a15aa02f6347d8cb04f633682c3))


### 🐛 Fixed Bugs

*  update to build version with normalized metadata — rjdbcm <rjdbcm@outlook.com>
([`2ccbd1c`](https://github.com/OZI-Project/ozi-templates/commit/2ccbd1c2f0860f690280129b812f9dcb29bf031c))

*  publish if needs.draft.outputs.drafted == 'true' — rjdbcm <rjdbcm@outlook.com>
([`244ddf4`](https://github.com/OZI-Project/ozi-templates/commit/244ddf4c8c74955689ec9a007efa6b09f9e75165))

*  fix repo name — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`959bab3`](https://github.com/OZI-Project/ozi-templates/commit/959bab31da5befd1e651ecb072fa7026e24cc9e9))

*  fix missing tag input to release — rjdbcm <rjdbcm@outlook.com>
([`a677875`](https://github.com/OZI-Project/ozi-templates/commit/a6778750e5546955daf528f22283bfb77c76fd93))

*  major_on_zero back to false — rjdbcm <rjdbcm@outlook.com>
([`8e76820`](https://github.com/OZI-Project/ozi-templates/commit/8e76820683aebe3f89f519ec2159ba815de7ca5c))

*  fix missing commit_parser_options — rjdbcm <rjdbcm@outlook.com>
([`ccf75ef`](https://github.com/OZI-Project/ozi-templates/commit/ccf75ef7f8ccc0cf99329f5a348dc45df84c536e))

*  fix commit_parser name — rjdbcm <rjdbcm@outlook.com>
([`26b9b7a`](https://github.com/OZI-Project/ozi-templates/commit/26b9b7a61c31170e1e77b6532d9d3ef3448a8505))


### ✨ Implemented Features

*  bump version — rjdbcm <rjdbcm@outlook.com>
([`83c01e5`](https://github.com/OZI-Project/ozi-templates/commit/83c01e5f8def35badc58f7b00bba58b2fa547c94))

*  revert angular commit parsing. — rjdbcm <rjdbcm@outlook.com>
([`1a8e395`](https://github.com/OZI-Project/ozi-templates/commit/1a8e3958989ed760de0494faef3c48797d13b3e4))


### Other


* Update pyproject.toml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`178143e`](https://github.com/OZI-Project/ozi-templates/commit/178143e956bb251585181c680d1278b99cc98650))

* Update pyproject.toml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`f4b6b38`](https://github.com/OZI-Project/ozi-templates/commit/f4b6b38ad98c1e22df02cf45c758fa7d664cd4ee))

* Update pyproject.toml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`63eb260`](https://github.com/OZI-Project/ozi-templates/commit/63eb260f9e4a916d80d226b890f385ee1fd463ad))

* fix(semantic-release): config ``major_on_zero = true`` — rjdbcm <rjdbcm@outlook.com>
([`e2e04ef`](https://github.com/OZI-Project/ozi-templates/commit/e2e04efdf3d1d93868d3d1653f547427e5b63b18))

* fix(readme-renderer): fix args to target readme copied during build — rjdbcm <rjdbcm@outlook.com>
([`d7ed57f`](https://github.com/OZI-Project/ozi-templates/commit/d7ed57f81d679006b0cf8125ee92d68b541e15de))

* style(isort): import sort — rjdbcm <rjdbcm@outlook.com>
([`fad659c`](https://github.com/OZI-Project/ozi-templates/commit/fad659c29b487e507396522e5edbb08923444ca8))

* fix(dist-depends): restore requirements.in — rjdbcm <rjdbcm@outlook.com>
([`3586f0f`](https://github.com/OZI-Project/ozi-templates/commit/3586f0f033a1f0d52c680c7964a5ab3b1ec8b006))

* fix(imports): remove blastpipe references — rjdbcm <rjdbcm@outlook.com>
([`97395ae`](https://github.com/OZI-Project/ozi-templates/commit/97395ae610647f20909152613dbd927447dc418b))

* fix(tests): add test_filter.py to build — rjdbcm <rjdbcm@outlook.com>
([`9b99d3a`](https://github.com/OZI-Project/ozi-templates/commit/9b99d3a060de90f41f12509e68f5b50f12705a08))

* style(isort): sort imports — rjdbcm <rjdbcm@outlook.com>
([`6faeeff`](https://github.com/OZI-Project/ozi-templates/commit/6faeeffed15231f5f3ac6f2f8628e78b430081d6))

* Update pyproject.toml — Eden Ross Duff, MSc <rjdbcm@outlook.com>
([`8dfad97`](https://github.com/OZI-Project/ozi-templates/commit/8dfad9728cb2934c388714f1e9a968000993dcd1))

* feat(package): mirror blastpipe 2024.11.7 ozi_templates — rjdbcm <rjdbcm@outlook.com>
([`2987d9c`](https://github.com/OZI-Project/ozi-templates/commit/2987d9c6b8ebc723ed3dc39334794c7fd764709a))

## 1.0.0 (2024-04-27)


### 💥


*  add load_environment() func — rjdbcm <rjdbcm@mail.umkc.edu>
([`7cb9510`](https://github.com/OZI-Project/ozi-templates/commit/7cb951045f3855ab6a301ca52d536d96e4a3f0c0))


### 🐛 Fixed Bugs

*  fix release workflow outputs so publish is not skipped. — rjdbcm <rjdbcm@outlook.com>
([`2ce8dd0`](https://github.com/OZI-Project/ozi-templates/commit/2ce8dd0f24f52f9c497dd9dd57be6bdcd917b010))

*  Fix publish workflow had ssh arguments still. — rjdbcm <rjdbcm@outlook.com>
([`77a8ede`](https://github.com/OZI-Project/ozi-templates/commit/77a8edef6915fc3324e0ac131500747a5a8d72f1))

*  fix name normalization in project and template.

Without normalization we get duplicate dist_info. — rjdbcm <rjdbcm@outlook.com>
([`d40e46a`](https://github.com/OZI-Project/ozi-templates/commit/d40e46ae36927546cca0fe76baa2c870ccd6a2a7))


### 🔥 Deleted Code or Files

*  delete template readme
([`33abd6c`](https://github.com/OZI-Project/ozi-templates/commit/33abd6c51075136fb8b40ba7c81e28a2b405f236))


### ✏️ Corrected Typos

*  correct project name
([`9df80d8`](https://github.com/OZI-Project/ozi-templates/commit/9df80d8511050ab6596f5b10f8d7dc41be0c0924))


### Other


* Initial clone of templates — rjdbcm <rjdbcm@mail.umkc.edu>
([`a8370f9`](https://github.com/OZI-Project/ozi-templates/commit/a8370f94cf621f3035ce6ac956fe96a752b005d2))

* Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] <support@github.com>
([`54566b3`](https://github.com/OZI-Project/ozi-templates/commit/54566b3f685b0a8757105c1ff8177eabdbe61d3e))

* Initial commit
([`6df66d3`](https://github.com/OZI-Project/ozi-templates/commit/6df66d3a74d25f7e06bb573249b8c065155b9358))
